ident_from_string

Function ident_from_string 

pub fn ident_from_string(s: &str) -> Result<Ident>
Create a new Ident from a string, automatically handling raw prefixes. If the input has a raw prefix, it creates a raw identifier. Otherwise, it creates a regular identifier.